/*
compile with

gcc -Wall -D__USE_INLINE__ EasyDT.c -o EasyDT -lauto
*/

#include <proto/exec.h>
#include <proto/dos.h>
#include <proto/graphics.h>
#include <proto/intuition.h>
#include <proto/datatypes.h>
#include <datatypes/pictureclass.h>
#include <string.h>

long min (long a,long b)
{
return (a < b ? a : b);
}

void DisplayImage (char *filename)

{
Object *dto;

if ((dto = NewDTObject (filename,
		DTA_GroupID,GID_PICTURE,
		PDTA_Remap,FALSE,
		TAG_END)))
	{
	struct BitMapHeader *bmhd = NULL;
	struct BitMap *bm;
	ULONG viewmodes = 0;
	ULONG *cregs = NULL;
	ULONG num_colors = 0;

	DoMethod (dto,DTM_PROCLAYOUT,NULL,TRUE);

	GetDTAttrs (dto,
		PDTA_BitMapHeader,&bmhd,
		PDTA_BitMap,&bm,
		PDTA_ModeID,&viewmodes,
		PDTA_CRegs,&cregs,
		PDTA_NumColors,&num_colors,
		TAG_END);

	if (bmhd)
		{
		struct Screen *myscreen;

		if ((myscreen = OpenScreenTags (NULL,
				SA_Width,  bmhd->bmh_Width,
				SA_Height, bmhd->bmh_Height,
				SA_Depth,  bmhd->bmh_Depth,
				SA_DisplayID, viewmodes,
				SA_Behind, TRUE,
				TAG_END)))
			{
			ULONG colortable[3*256+2];

			colortable[0] = num_colors << 16;
			memcpy (&colortable[1],cregs,3*4*num_colors);
			colortable[3*num_colors+1] = 0;
			LoadRGB32 (&myscreen->ViewPort,colortable);

			Printf ("Press Ctrl-C to quit.\n");

			BltBitMapRastPort (bm,0,0,
				&myscreen->RastPort,0,0,
				min(myscreen->Width,bmhd->bmh_Width),
				min(myscreen->Height,bmhd->bmh_Height),
				0xc0);

			ScreenToFront (myscreen);
			Wait (SIGBREAKF_CTRL_C);

			CloseScreen (myscreen);
			}
		else
			Printf ("Can't open screen.\n");
		}
	else
		Printf ("This file has no bitmap header.\n");

	DisposeDTObject (dto);
	}
else
	Printf ("Can't open file '%s'\n",filename);
}


int main (int argc,char **argv)

{
if (argc != 2 || strcmp(argv[1],"?") == 0)
	{
	Printf ("Usage: %s <filename>\n",argv[0]);
	return (RETURN_FAIL);
	}

DisplayImage (argv[1]);

return (RETURN_OK);
}

